import java.awt.Point;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.StringSelection;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.awt.geom.Point2D;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JTextArea;
import javax.swing.SwingConstants;
import javax.swing.TransferHandler;

import com.mindfusion.diagramming.ControlNode;
import com.mindfusion.diagramming.Diagram;
import com.mindfusion.diagramming.DiagramNode;
import com.mindfusion.diagramming.DiagramView;
import com.mindfusion.diagramming.MouseInputMode;
import com.mindfusion.diagramming.TableNode;


public class FormEditorTransferHandler extends TransferHandler
{
	public int getSourceActions(JComponent c)
	{
		return COPY;
	}
	
	protected Transferable createTransferable(JComponent c)
	{
		return new StringSelection(((JList<?>)c).getSelectedValue().toString() );
	}
	
	protected void exportDone(JComponent c, Transferable t, int action)
	{
		
	}
	
	public boolean importData(JComponent c, Transferable t)
	{
		if (canImport(c, t.getTransferDataFlavors()))
		{
			// Can only drop on the flow chart control
			if (!(c instanceof DiagramView))
				return false;

			if (t.isDataFlavorSupported(DataFlavor.stringFlavor))
			{
				try
				{
					String text = (String)t.getTransferData(DataFlavor.stringFlavor);

					DiagramView view = (DiagramView)c;
					Diagram diagram = view.getDiagram();

					Point mousePosition = view.getMousePosition(true);
					Point2D diagPoint = view.deviceToDoc(mousePosition);
					DiagramNode node = diagram.getNodeAt(diagPoint);
					if (node instanceof TableNode)
					{
						TableNode table = (TableNode)node;
						int lastRow = table.addRow();
						table.getCell(0,  lastRow).setText(text);
					}
					else
					{
						diagram.getFactory().createTableNode(
							diagPoint.getX(), diagPoint.getY(), 50, 80, 1, 0);
					}
				}
				catch (Exception e)
				{
					e.printStackTrace();
				}
			}
		}

		return false;
	}
	
	public boolean canImport(JComponent c, DataFlavor[] flavors)
	{
		if (!(c instanceof DiagramView))
			return false;

		for (int i = 0; i < flavors.length; i++)
		{
			if (DataFlavor.stringFlavor.equals(flavors[i]))
				return true;
		}

		return false;
	}
		
	private static final long serialVersionUID = 1L;
}